.. _navier_stokes-utils:

navier_stokes/utils.py
======================

**Description**

missing description!



:download:`source code </../sfepy/examples/navier_stokes/utils.py>`

.. literalinclude:: /../sfepy/examples/navier_stokes/utils.py

